@@ -28,6 +28,7 @@ func (t *Trigger) SetDefaults(ctx context.Context) {
 		return
 	}
 	triggerSpecBindingArray(t.Spec.Bindings).defaultBindings()
+	templateNameToRef(&t.Spec.Template)
 }
 
 // set default TriggerBinding kind for Bindings in TriggerSpec
@@ -40,3 +41,11 @@ func (t triggerSpecBindingArray) defaultBindings() {
 		}
 	}
 }
+
+func templateNameToRef(template *TriggerSpecTemplate) {
+	name := template.DeprecatedName
+	if name != "" && template.Ref == nil {
+		template.Ref = &name
+		template.DeprecatedName = ""
+	}
+}
